pub fn compute_diff_impact(
graph: &InMemoryGraph,
hunks: &[DiffHunk],
symbols: &[SymbolNode],
max_depth: usize,
) -> DiffImpactReportExpand description
Combine change detection with blast radius for a full diff impact report.
pub fn compute_diff_impact(
graph: &InMemoryGraph,
hunks: &[DiffHunk],
symbols: &[SymbolNode],
max_depth: usize,
) -> DiffImpactReportCombine change detection with blast radius for a full diff impact report.