pub fn compute_sensitivity(
symbols: &[SymbolNode],
patterns: &[String],
) -> HashMap<String, f64>Expand description
Compute security sensitivity: 1.0 if symbol name or decorators match a pattern, 0.0 otherwise. Uses word-boundary matching: patterns match against segments of the qualified name and decorators.